@@ -1,32 +1,25 @@
 # Continuous pointwise ranks
 #
-# Calculate continuous pointwise ranks of the curves from the largest (smallest rank)
-# to the smallest (largest rank) for the data in the vector y (corresponding to functions at an argument value (r)).
-contrank <- function(y, ordery=order(y, decreasing=TRUE)) {
-  Nfunc <- length(y)
+# Calculate continuous ranks in the same way as \code{\link{rank}}.
+contrank <- function(y) {
+  ordery <- order(y)
+  n <- length(y)
   y <- y[ordery]
-  ties <- y[1:(Nfunc-2)] == y[3:Nfunc] # same as j = 2:(Nfunc-1); ties <- y[j-1] == y[j+1]
-  RR <- 0:(Nfunc-1) # Initialize the vector with j-1 (values for the case of ties)
-  RR[1] <- exp(-(y[1]-y[2])/(y[2]-y[Nfunc]))
-  if(!any(ties)) {
-    RR[2:(Nfunc-1)] <- 1:(Nfunc-2)+(y[1:(Nfunc-2)]-y[2:(Nfunc-1)])/(y[1:(Nfunc-2)]-y[3:Nfunc])
-    # same as j <- 2:(Nfunc-1); RR[j] <- j-1+(y[j-1]-y[j])/(y[j-1]-y[j+1])
-  }
-  else { # The case of some ties
-    j <- (2:(Nfunc-1))[!ties]
-    jm1 <- j-1
-    RR[j] <- jm1+(y[jm1]-y[j])/(y[jm1]-y[j+1])
-    # Treat ties
-    j <- 1
-    while(j <= Nfunc-2) {
-      k <- 1
-      if(ties[j]) {
-        k <- 3; S <- 3*j+3
-        while(j+k <= Nfunc && y[j] == y[j+k]) { k <- k+1; S <- S+j+k }
-        for(t in j:(j+k-1)) { RR[t] <- S/k }
-      }
-      j <- j+k
-    }
+  ties <- y[1:(n-2)] == y[3:n] # same as j = 1:(n-2); ties <- y[j-1] == y[j+1]
+  # If there are two tied values then the tree following expressions magically yield the right result
+  # and it's not necessary to handle the ties specially
+  RR <- numeric(n)
+  RR[1] <- exp(-(y[1]-y[2])/(y[2]-y[n]))
+  RR[n] <- n - exp(-(y[n]-y[n-1])/(y[n-1]-y[1]))
+  RR[2:(n-1)] <- 1:(n-2)+(y[1:(n-2)]-y[2:(n-1)])/(y[1:(n-2)]-y[3:n])
+
+  if(any(ties)) { # The case of some ties
+    ordrank <- rank(y, ties.method = "average")
+    # Find all elements occuring at least twice.
+    # It would be enough to consider only elements occuring at least three times, but it's okay.
+    ties <- y[1:(n-1)] == y[2:n]
+    ties <- c(ties, FALSE) | c(FALSE, ties)
+    RR[ties] <- ordrank[ties] - 0.5
   }
   RR[ordery] <- RR
   RR
@@ -36,38 +29,26 @@ contrank <- function(y, ordery=order(y, decreasing=TRUE)) {
 find_calc_pointwiserank <- function(measure, alternative) {
   if(measure %in% c('rank', 'erl')) {
     avrank <- function(x) { rank(x, ties.method = "average") }
-    switch(alternative,
-           "two.sided" = {
-             function(x) {
-               loranks <- avrank(x)
-               hiranks <- length(x)+1-loranks
-               pmin(loranks, hiranks)
-             }
-           },
-           "less" = {
-             function(x) { avrank(x) }
-           },
-           "greater" = {
-             function(x) { length(x)+1-avrank(x) }
-           })
+    minrank <- 1
   }
   else if(measure %in% c('cont', 'area')) {
-    switch(alternative,
-           "two.sided" = {
-             function(y) {
-               ordery <- order(y, decreasing = TRUE)
-               hiranks <- contrank(y, ordery)
-               loranks <- contrank(-y, rev(ordery))
-               pmin(loranks, hiranks)
-             }
-           },
-           "less" = {
-             function(y) { contrank(-y) }
-           },
-           "greater" = {
-             function(y) { contrank(y) }
-           })
+    avrank <- function(x) { contrank(x) }
+    minrank <- 0
   } else { stop("Internal error in GET.")}
+  switch(alternative,
+         "two.sided" = {
+           function(x) {
+             loranks <- avrank(x)
+             hiranks <- length(x)+minrank-loranks
+             pmin(loranks, hiranks)
+           }
+         },
+         "less" = {
+           function(x) { avrank(x) }
+         },
+         "greater" = {
+           function(x) { length(x)+minrank-avrank(x) }
+         })
 }
 
 # Compute rank(x, ties.method="average") where x is the columns of a matrix.
@@ -94,6 +75,58 @@ rank_matrix_cols <- function(x) {
   ranks
 }
 
+# @param erlhistn (numeric) Use histogram approximation for erl with erlhistn largest ranks. 0 means no approximation.
+# Functionality for functional ordering based on a curve set
+individual_partial_forder <- function(curve_set, measure = c('erl', 'rank', 'cont', 'area'),
+                                      alternative, erlhistn=0) {
+  measure <- match.arg(measure)
+
+  curve_set <- convert_envelope(curve_set)
+
+  all_curves <- data_and_sim_curves(curve_set)
+  Nfunc <- dim(all_curves)[1]
+  nr <- curve_set_narg(curve_set)
+
+  # Calculate pointwise ranks for each argument value (r)
+  calc_pointwiserank <- find_calc_pointwiserank(measure, alternative)
+  for(i in 1:nr) {
+    all_curves[,i] <- calc_pointwiserank(all_curves[,i]) # overwriting curves by their ranks
+  }
+  allranks <- all_curves
+
+  # Calculate measures from the pointwise ranks
+  applyfuncs <- function(f) {
+    sapply(1:nrow(allranks), function(i) { f(allranks[i,]) })
+  }
+  # Compute highest ranks (r) and their counts (c) for the n highest ranks
+  # return r_1,-c_1,r_2,-c_2,r_3,-c_3,...,r_n,-c_n
+  # ordering by the return value gives the same order as sorting by the ranks themselves
+  # when there are no ties in the return values
+  erlhist <- function(x) {
+    y <- rle(sort(x))
+    c(matrix(c(y$values[1:erlhistn], -y$lengths[1:erlhistn]), byrow=TRUE, nrow=2))
+  }
+  partialarea <- function(cont) {
+    rank <- ceiling(min(cont))
+    area <- sum(rank - cont[cont <= rank])
+    c(rank, area)
+  }
+  switch(measure,
+         rank = ,
+         cont = applyfuncs(min),
+         area = applyfuncs(partialarea),
+         erl = {
+           if(erlhistn > 0) applyfuncs(erlhist)
+           else applyfuncs(sort)
+         }
+         )
+}
+
+scale_ranks <- function(distance, measure) {
+  if(measure=="rank") distance
+  else distance/length(distance)
+}
+
 # Functionality for functional ordering based on a curve set
 individual_forder <- function(curve_set,
                               measure = 'erl', scaling = 'qdir',
@@ -101,7 +134,7 @@ individual_forder <- function(curve_set,
                               use_theo = TRUE,
                               probs = c(0.025, 0.975), quantile.type = 7) {
   possible_measures <- c('rank', 'erl', 'cont', 'area', 'max', 'int', 'int2')
-  if(!(measure %in% possible_measures)) stop("Unreasonable measure argument!\n")
+  if(!(measure %in% possible_measures)) stop("Unreasonable measure argument!")
 
   curve_set <- convert_envelope(curve_set)
 
@@ -112,62 +145,138 @@ individual_forder <- function(curve_set,
   }
   else {
     alternative <- match.arg(alternative)
-    data_and_sim_curves <- data_and_sim_curves(curve_set)
-    Nfunc <- dim(data_and_sim_curves)[1]
+    Nfunc <- curve_set_nfunc(curve_set)
     nr <- curve_set_narg(curve_set)
-
-    # Calculate pointwise ranks for each argument value (r)
-    calc_pointwiserank <- find_calc_pointwiserank(measure, alternative)
-    for(i in 1:nr) {
-      data_and_sim_curves[,i] <- calc_pointwiserank(data_and_sim_curves[,i]) # overwriting curves by their ranks
-    }
-    allranks <- data_and_sim_curves
-
-    # Calculate measures from the pointwise ranks
-    applyfuncs <- function(f) {
-      sapply(1:nrow(allranks), function(i) { f(allranks[i,]) })
-    }
-    # Compute highest ranks (r) and their counts (c) for the n highest ranks
-    # return r_1,-c_1,r_2,-c_2,r_3,-c_3,...,r_n,-c_n
-    # ordering by the return value gives the same order as sorting by the ranks themselves
-    # when there are no ties in the return values
-    erlrle <- function(x, n=6) {
-      y <- rle(sort(x))
-      c(matrix(c(y$values[1:n], -y$lengths[1:n]), byrow=TRUE, nrow=2))
+    # If the curve_set is larger than 80 MB
+    # and nr > 2*6
+    # then use histogram approximation for erl
+    erlhistn <- 0
+    if(measure == "erl" && Nfunc*nr > 10*2^20 && nr > 12) {
+      erlhistn <- 6
     }
+    partial_forder <- individual_partial_forder(curve_set, measure, alternative, erlhistn)
     switch(measure,
            rank = {
-             distance <- applyfuncs(min) # extreme ranks R_i
+             distance <- partial_forder
            },
            erl = {
-             # If the curve_set is larger than 80 MB
-             # and nr > 2*n (in erlrle)
-             # then use erlrle, otherwise sort
-             if(length(data_and_sim_curves) > 10*2^20 && nr > 12)
-               sortranks <- applyfuncs(erlrle)
-             else
-               sortranks <- applyfuncs(sort)
-             distance <- rank_matrix_cols(sortranks) / Nfunc
+             distance <- rank_matrix_cols(partial_forder)
            },
            cont = {
-             distance <- applyfuncs(min)
-             if(alternative == "two.sided")
-               distance <- distance / ceiling(Nfunc/2)
-             else
-               distance <- distance / (Nfunc-1)
+             distance <- partial_forder
            },
            area = {
-             distance <- applyfuncs(function(x) { sum(pmin(ceiling(min(x)), x)) })
-             if(alternative == "two.sided")
-               distance <- distance / (ceiling(Nfunc/2)*nr)
-             else
-               distance <- distance / ((Nfunc-1)*nr)
+             distance <- partial_forder[1,] - partial_forder[2,] / nr
            })
+    distance <- scale_ranks(distance, measure)
   }
-  names(distance) <- rownames(data_and_sim_curves)
+  names(distance) <- curve_set_funcnames(curve_set)
   list(distance = distance, measure = measure)
 }
 
+combine_area_forder1 <- function(x, nr) {
+  ranks <- x[1,]
+  areas <- x[2,]
+  rank <- min(ranks)
+  area <- sum(areas[ranks==rank])
+  rank - area / nr
+}
+combine_area_forder <- function(parts, nr) {
+  simnames <- colnames(parts[[1]])
+  Nfunc <- dim(parts[[1]])[2]
+  a <- array(unlist(parts), dim=c(dim(parts[[1]]), length(parts)))
+  area <- sapply(1:Nfunc, function(i) combine_area_forder1(a[,i,], nr))
+  names(area) <- simnames
+  area
+}
+
+# x <- c(1,-3, 2,-1, 4,-1, NA, NA, 1,-2, 3,-1, 4,-3, NA,NA)
+# n <- 5
+# stopifnot(all.equal(GET:::combine_erl_forder1(x, n), c(1,-5, 2,-1, 3,-1, 4,-4, NA,NA)))
+combine_erl_forder1 <- function(x, n) {
+  values <- x[c(TRUE, FALSE)]
+  counts <- x[c(FALSE, TRUE)]
+  newvalues <- sort(unique(values))[1:n]
+  newcounts <- unsplit(lapply(split(counts, values), sum), newvalues)
+  c(rbind(newvalues, newcounts))
+}
+#' @importFrom stats setNames
+combine_erl_forder <- function(parts) {
+  simnames <- colnames(parts[[1]])
+  Nfunc <- dim(parts[[1]])[2]
+  erln <- dim(parts[[1]])[1]/2
+  a <- array(unlist(parts), dim=c(dim(parts[[1]]), length(parts)))
+  erlrle <- sapply(1:Nfunc, function(i) combine_erl_forder1(c(a[,i,]), erln))
+  setNames(rank_matrix_cols(erlrle), simnames)
+}
+
+#' Functional ordering in parts
+#'
+#' If the functional data doesn't comfortably fit in memory it is possible to
+#' compute functional ordering by splitting the domain of the data (voxels in
+#' a brain image), using \code{partial_forder} on each part and finally
+#' combining the results with \code{combine_forder}.
+#'
+#' @param curve_set A \code{curve_set} object, usually a part of a larger \code{curve_set}.
+#' @seealso \code{\link{forder}}
+#' @return
+#' @inheritParams forder
+#' @examples
+#' data("abide_9002_23")
+#' \dontshow{
+#' ## Check that partial_forder gives the same result as forder
+#' cset <- frank.flm(nsim=19, formula.full = Y ~ Group + Sex + Age,
+#'                   formula.reduced = Y ~ Group + Sex,
+#'                   curve_sets = list(Y = abide_9002_23$curve_set),
+#'                   factors = abide_9002_23$factors, savefuns = "return")
+#' p1 <- partial_forder(cset[1:100,], measure="area")
+#' p2 <- partial_forder(cset[-(1:100),], measure="area")
+#' stopifnot(all.equal(combine_forder(list(p1, p2)), forder(cset, measure="area")))
+#' p1 <- partial_forder(cset[1:100,], measure="cont")
+#' p2 <- partial_forder(cset[-(1:100),], measure="cont")
+#' stopifnot(all.equal(combine_forder(list(p1, p2)), forder(cset, measure="cont")))
+#' p1 <- partial_forder(cset[1:100,], measure="erl")
+#' p2 <- partial_forder(cset[-(1:100),], measure="erl")
+#' stopifnot(all.equal(combine_forder(list(p1, p2)), forder(cset, measure="erl")))
+#' }
+#' res <- lapply(list(1:100, 101:200, 201:261), function(part) {
+#'   set.seed(123) # When using partial_forder, all parts must use the same seed.
+#'   fset <- frank.flm(nsim=99, formula.full = Y ~ Group + Sex + Age,
+#'                   formula.reduced = Y ~ Group + Sex,
+#'                   curve_sets = list(Y = abide_9002_23$curve_set[part,]),
+#'                   factors = abide_9002_23$factors, savefuns = "return")
+#'   partial_forder(fset, measure="erl")
+#' })
+#' combine_forder(res)
+#' @export
+partial_forder <- function(curve_set,
+                           measure = c('erl', 'rank', 'cont', 'area'),
+                           alternative = c("two.sided", "less", "greater")) {
+  measure <- match.arg(measure)
+  alternative <- match.arg(alternative)
+  res <- individual_partial_forder(curve_set, measure = measure, alternative = alternative, erlhistn = 6)
+  if(is.vector(res)) names(res) <- curve_set_funcnames(curve_set)
+  else colnames(res) <- curve_set_funcnames(curve_set)
+  list(data=res, measure=measure, nr=curve_set_narg(curve_set))
+}
+
+#' @param ls List of objects returned by partial_forder
+#' @return See \code{\link{forder}}
+#' @rdname partial_forder
+#' @export
+combine_forder <- function(ls) {
+  partialforders <- lapply(ls, getElement, name="data")
+  nr <- sum(sapply(ls, getElement, name="nr"))
+  measures <- sapply(ls, getElement, name="measure")
+  if(!all(measures[1] == measures)) stop("All parts must have been produced using the same measure.")
+  distance <- switch(measures[1],
+                     rank=,
+                     cont=do.call(pmin, partialforders),
+                     erl=combine_erl_forder(partialforders),
+                     area=combine_area_forder(partialforders, nr))
+  scale_ranks(distance, measures[1])
+}
+
 # Functionality for functional ordering based on several curve sets
 combined_forder <- function(curve_sets, ...) {
   ntests <- length(curve_sets)
@@ -195,8 +304,7 @@ combined_forder <- function(curve_sets, ...) {
 #'
 #' Given a \code{curve_set} (see \code{\link{create_curve_set}} for how to create such an object)
 #' or an \code{\link[spatstat]{envelope}} object,
-#' which contains both the data curve (or function or vector) \eqn{T_1(r)}{T_1(r)} and
-#' the simulated curves \eqn{T_2(r),\dots,T_{s+1}(r)}{T_2(r),...,T_(s+1)(r)},
+#' which contains curves \eqn{T_1(r),\dots,T_s(r)}{T_1(r),...,T_s(r)},
 #' the functions are ordered from the most extreme one to the least extreme one
 #' by one of the following measures (specified by the argument \code{measure}).
 #' Note that \code{'erl'}, \code{'cont'} and \code{'area'} were proposed as a refinement to
@@ -212,16 +320,18 @@ combined_forder <- function(curve_sets, ...) {
 #' specific r-value among the corresponding values of the s other curves such that the lowest
 #' ranks correspond to the most extreme values of the curves. How the pointwise ranks are determined
 #' exactly depends on the whether a one-sided (\code{alternative} is "less" or "greater") or the
-#' two-sided test (\code{alternative="two.sided"}) is chosen, for details see
-#' Mrkvička et al. (2017, page 1241) or Mrkvička et al. (2018, page 6).
+#' two-sided test (\code{alternative="two.sided"}) is chosen.
 #'  \item \code{'erl'}: extreme rank length (Myllymäki et al., 2017).
 #'  Considering the vector of pointwise ordered ranks \eqn{\mathbf{R}_i}{RP_i} of the ith curve,
 #'  the extreme rank length measure \eqn{R_i^{erl}}{Rerl_i} is equal to
-#' \deqn{R_i^{erl} = \frac{1}{s+1}\sum_{j=1}^{s+1} \mathbf{1}(\mathbf{R}_j "<" \mathbf{R}_i)}{Rerl_i = \sum_{j=1}^{s} 1(RP_j "<" RP_i) / (s + 1)}
+#' \deqn{R_i^{erl} = \frac{1}{s}\sum_{j=1}^{s} \mathbf{1}(\mathbf{R}_j "<" \mathbf{R}_i)}{Rerl_i = \sum_{j=1}^{s} 1(RP_j "<" RP_i) / s}
 #' where \eqn{\mathbf{R}_j "<" \mathbf{R}_i}{RP_j "<" RP_i} if and only if
 #' there exists \eqn{n\leq d}{n<=d} such that for the first k, \eqn{k<n}{k<n}, pointwise ordered
 #' ranks of \eqn{\mathbf{R}_j}{RP_j} and \eqn{\mathbf{R}_i}{RP_i} are equal and the n'th rank of
 #' \eqn{\mathbf{R}_j}{RP_j} is smaller than that of \eqn{\mathbf{R}_i}{RP_i}.
+#' The scaling by \deqn{s}{s} is applied to normalize the ranks following Mrkvička et al. (2019)
+#' and Narisetty and Nair (2016).
+#'
 #'  \item \code{'cont'}: continuous rank (Hahn, 2015; Mrkvička et al., 2019)
 #' based on minimum of continuous pointwise ranks
 #'  \item \code{'area'}: area rank (Mrkvička et al., 2019) based on area between continuous
@@ -233,6 +343,7 @@ combined_forder <- function(curve_sets, ...) {
 #' These measures are largest for the most extreme functions and smallest for the least extreme ones.
 #' The arguments \code{use_theo} and \code{probs} are relevant for these measures only (otherwise ignored).
 #' }
+#' For details see Myllymäki and Mrkvička et al. (2020, Section 2)
 #'
 #' @return A vector containing one of the above mentioned measures k for each of the functions
 #' in the curve set. If the component \code{obs} in the curve set is a vector, then its measure
@@ -256,16 +367,19 @@ combined_forder <- function(curve_sets, ...) {
 #' @param quantile.type As type argument of \code{\link[stats]{quantile}}, how to
 #' calculate quantiles for 'q' or 'qdir'.
 #' @export
+#' @seealso \code{\link{partial_forder}}
 #' @references
 #' Hahn U (2015). “A note on simultaneous Monte Carlo tests.” Technical report, Centre for Stochastic Geometry and advanced Bioimaging, Aarhus University.
 #'
-#' Mrkvička, T., Hahn, U. and Myllymäki, M. (2018). A one-way ANOVA test for functional data with graphical interpretation. arXiv:1612.03608 [stat.ME]
+#' Mrkvička, T., Myllymäki, M., Jilek, M. and Hahn, U. (2020) A one-way ANOVA test for functional data with graphical interpretation. Kybernetika 56 (3), 432-458. doi: 10.14736/kyb-2020-3-0432
 #'
 #' Mrkvička, T., Myllymäki, M. and Narisetty, N. N. (2019) New methods for multiple testing in permutation inference for the general linear model. arXiv:1906.09004 [stat.ME]
 #'
 #' Myllymäki, M., Grabarnik, P., Seijo, H. and Stoyan. D. (2015). Deviation test construction and power comparison for marked spatial point patterns. Spatial Statistics 11: 19-34. doi: 10.1016/j.spasta.2014.11.004
 #'
 #' Myllymäki, M., Mrkvička, T., Grabarnik, P., Seijo, H. and Hahn, U. (2017). Global envelope tests for spatial point patterns. Journal of the Royal Statistical Society: Series B (Statistical Methodology), 79: 381–404. doi: 10.1111/rssb.12172
+#'
+#' Narisetty, N. N. and Nair, V. J. (2016) Extremal depth for functional data and applications. Journal of the American Statistical Association, 111, 1705–1714.
 #' @examples
 #' if(requireNamespace("fda", quietly = TRUE)) {
 #'   # Consider ordering of the girls in the Berkeley Growth Study data
